
/**
 * \file utils.h
 *
 *  14.02.2011 psa:  Various useful non ansi-c functions and defines
 */

#ifndef _UTILS_H_
#define _UTILS_H_

#if __cplusplus
extern "C" {
#endif
#ifdef _NEVER_DEFINED_ 
}
#endif

//======================================================================
// switches for debug output on terminal
//----------------------------------------------------------------------
#define OFF_T (0x00)
#define ERR_T (0x01)
#define WRN_T (0x02)
#define INF_T (0x04)
#define DBG_T (0x08)
#define ALL_T (0x0F)
//----------------------------------------------------------------------
#define TRACE_E  if(FPGA.DebugTrace & ERR_T) printf
#define TRACE_W  if(FPGA.DebugTrace & WRN_T) printf
#define TRACE_I  if(FPGA.DebugTrace & INF_T) printf
#define TRACE_D  if(FPGA.DebugTrace & DBG_T) printf

//-----------------------------------------------------------------
// functions 
//-----------------------------------------------------------------

//--------------------------------------------------------------------
char *strlwr(char *string);
char *strupr(char *string);
char *itoa(s32 value, char *string, int radix);
char *utoa(u32 value, char *string, int radix);

//--------------------------------------------------------------------
// Converts an integer with a size of [n] bytes to a hex-digit string.
// With macro for simplified _int2str() function call
//--------------------------------------------------------------------
#define int2hex(val,str) _int2hex((u08*)&(val),(str),sizeof((val)))
u08* _int2hex(u08 *intval, u08 *hexstr, u08 n);

//--------------------------------------------------------------------
// Converts a hex-digit string to an integer with a size of [n] bytes.
// With macro for simplified _str2int() function call
//--------------------------------------------------------------------
#define hex2int(str,val) _hex2int((char*)(str),(u08*)&(val),sizeof((val)))
void _hex2int(char *hexstr, u08 *intval, u08 n);

//---------------------------------------------------------------------
// Converts a sequence of [n] bytes to a hex-digit string.
//---------------------------------------------------------------------
#define bin2hex(val,str,len) _bin2hex((u08*)&(val),(str),(len))
u08* _bin2hex(u08 *intval, u08 *hexstr, u08 n);

//---------------------------------------------------------------------
// Converts a hex-digit string to a sequence of [n] bytes.
// if [n] is zero, the sequenze will be limited by the stringlength
// The length of the sequence is provided as return value.
//---------------------------------------------------------------------
#define hex2bin(str,val,len) _hex2bin((str),(u08*)(val),(len))
u08 _hex2bin(char *hexstr, u08 *intval, u08 n);

#if __cplusplus
}
#endif    // __cplusplus
#endif    // include gard
